@@ -140,10 +140,12 @@ pub(crate) async fn handle_command(
 pub(crate) async fn handle_pull(cmd: PullCommand) -> Result<String, Box<dyn ::std::error::Error>> {
     let image: Reference = cmd.url.parse().unwrap();
     let spinner = match cmd.output.kind {
-        OutputKind::Text if output_destination() == OutputDestination::Cli => Some(Spinner::new(
-            Spinners::Dots12,
-            format!(" Downloading {} ...", image.whole()),
-        )),
+        OutputKind::Text { .. } if output_destination() == OutputDestination::Cli => {
+            Some(Spinner::new(
+                Spinners::Dots12,
+                format!(" Downloading {} ...", image.whole()),
+            ))
+        }
         _ => None,
     };
     info!("Downloading {}", image.whole());
@@ -305,10 +307,12 @@ fn validate_provider_archive(
 
 pub(crate) async fn handle_push(cmd: PushCommand) -> Result<String, Box<dyn ::std::error::Error>> {
     let spinner = match cmd.output.kind {
-        OutputKind::Text if output_destination() == OutputDestination::Cli => Some(Spinner::new(
-            Spinners::Dots12,
-            format!(" Pushing {} to {} ...", cmd.artifact, cmd.url),
-        )),
+        OutputKind::Text { .. } if output_destination() == OutputDestination::Cli => {
+            Some(Spinner::new(
+                Spinners::Dots12,
+                format!(" Pushing {} to {} ...", cmd.artifact, cmd.url),
+            ))
+        }
         _ => None,
     };
     info!(" Pushing {} to {} ...", cmd.artifact, cmd.url);
@@ -485,7 +489,7 @@ mod tests {
                     digest.unwrap(),
                     "sha256:a17a163afa8447622055deb049587641a9e23243a6cc4411eb33bd4267214cf3"
                 );
-                assert_eq!(output.kind, OutputKind::Text);
+                assert_eq!(output.kind, OutputKind::Text { max_width: 0 });
                 assert_eq!(opts.user.unwrap(), "user");
                 assert_eq!(opts.password.unwrap(), "password");
             }
