@@ -315,6 +315,10 @@ impl WashRepl {
             Key::Char(c) if c == '\n' => {
                 let cmd: String = self.input_state.input.iter().collect();
                 let iter = cmd.split_ascii_whitespace();
+
+                crate::util::set_max_text_output_width(
+                    self.output_state.lock().unwrap().output_width - 2,
+                );
                 let cli = ReplCli::from_iter_safe(iter);
 
                 self.input_state
